@@ -1,36 +1,33 @@
 # x <- c('Aconitum vulgare', 'Homalothecium lutescens')
-#########################################################
-## function tax
-#########################################################
+######################################################## #
+## function tax  ####
+######################################################## #
 
 "tax" <- function(...) UseMethod("tax")
 
-tax.default <- function(x, refl, detailed = FALSE, syn = TRUE, concept = NULL, strict = FALSE, vernacular = FALSE, simplify=FALSE, quiet = FALSE, reflist.type = 'Turboveg', ...) {
+tax.default <- function(x, refl, detailed = FALSE, syn = TRUE, concept = NULL, strict = FALSE, simplify = FALSE, quiet = FALSE, reflist.type = 'Turboveg', ...) {
 	tv_home <- tv.home()
   if(missing(x)) stop('x is missing!')
 ###------ internal functions
-#########################################################
+######################################################## #
 # Subsetting
-select.taxa <- function(x, species, strict = FALSE, vernacular = FALSE, simplify = FALSE, genus = TRUE, epithet = TRUE, ...) {
+select.taxa <- function(x, species, strict = FALSE, simplify = FALSE, genus = TRUE, epithet = TRUE, ...) {
   if(is.factor(x)) x <- as.character(x)
   if(is.numeric(x) | is.integer(x))
     ## Tax numbers
-    l <- species[match(x, species$TaxonUsageID),]  else
-  if(vernacular) {
-    stop()
-    if(strict)  l <- species[species$VernacularName %in% x, ] else
-      l <- species[grepl(x, species$VernacularName), ]
-    } else { 
-  if(is.character(x)) {															## Selecting by string
+    l <- species[match(x, species$TaxonUsageID),] else { 															## Selecting by string
   	if(nchar(x[1]) == 7 & x[1] == toupper(x[1]))  { ## Lettercode
       l <- species[species$LETTERCODE %in% x,]
       if(nrow(l) > 1) l <- l[!l$SYNONYM,]
     } else {
-#    	if(all(sapply(x, function(x) nchar(x) == 36))) {
-#    	  message('x is interpreted as 36 character representation of a GUID Taxon ID.')
-#       l <- species[match(x, species$TaxonUsageID),] ## GUID Tax ID's		
-#     }   																				## Taxnames
-    x <- taxname.abbr(x, hybrid = c('substitute'))
+   	if(all(sapply(x, function(x) nchar(x) == 36))) {
+   	  if(is.null(getOption('UUID.taxon'))) {
+   	      message('x is interpreted as 36 character representation of a UUID Taxon ID.')
+   	      options(UUID.taxon = TRUE)
+   	  }
+      l <- species[match(x, species$TaxonUsageID), ] ## GUID Tax ID's
+    } else {   																				## Taxnames
+    x <- taxname.abbr(x, ...)
 	if(simplify) {
 #  		if('simplified' %in% names(species)) species$TaxonName <- species$simplified else {
 #		  	species$TaxonName <- taxname.simplify(species$TaxonName, genus, epithet, ...)
@@ -55,7 +52,7 @@ select.taxa <- function(x, species, strict = FALSE, vernacular = FALSE, simplify
 # refl='GermanSL 1.2'; detailed=FALSE; vernacular=FALSE;simplify=FALSE; strict=FALSE
 # if(!is.null(concept)) species <- concept.FUN(species, concept)
   
-#### beginning to execute function tax()
+#### beginning to execute function tax() ####
 if(missing(refl)) {
   refl <- if(!is.null(getOption('tv.refl'))) getOption('tv.refl') else tv.refl(tv_home=tv_home)
   if(!quiet) message('Reference list used:', refl)	
@@ -66,7 +63,7 @@ if(length(x) == 0 | is.na(x[1])) stop('Input taxon value is missing.')
 
 if(tolower(x[1]) != 'all') {
 	if(simplify) species$originalTaxonName <- species$TaxonName
-	species <- select.taxa(x, species, strict, vernacular, simplify, ...)
+	species <- select.taxa(x, species, strict, simplify, ...)
  }
 if(nrow(species) > 0) {
   if(!syn) species <- species[species$SYNONYM == FALSE,]
