@@ -3,6 +3,7 @@ tv.eco <- function (...) stop('This function is deprecated, use tv.traits instea
 tv.traits <- function (db, trait.db = 'ecodbase.dbf', refl, ...) {
     tv_home <- tv.home()
     if(missing(refl))  refl <- if(missing(db)) tv.refl() else tv.refl(db = db)
+    if(tools::file_ext(trait.db) != 'dbf') stop('Only implemented for dBas file format.')
     ecodb <- read.dbf(file.path(tv_home, 'Species', refl, trait.db), as.is = TRUE)
     names(ecodb) <- TCS.replace(names(ecodb))
     empty <- function(x) all(is.na(x) | x == 0)
@@ -17,7 +18,6 @@ tv.traits <- function (db, trait.db = 'ecodbase.dbf', refl, ...) {
 # ecoDB <- apply(ecodb, 2, function(x) type.convert(as.character(x))) # doesnt work 
     ecoDB <- ecodb
 #    for(i in 1:ncol(ecodb)) if(is.factor(ecodb[,i])) {
-#       ecoDB[,i] <- iconv(as.character(ecodb[,i], "CP437", ""))
 #       ecoDB[,i] <- type.convert(ecoDB[,i]) }
 #     for(i in 1:ncol(ecoDB))  if(class(ecodb[,i]) != class(ecoDB[,i]))
 #       ecoDB$ABBREVIAT <- as.character(ecoDB$ABBREVIAT)
